% CRLQG.M:  Continuous-time random LQG problem generation.
%
%          function [p,g,c,v,w,q,r]=crlqg(nx,nu,ny,mrp,seed);
%
% Input:
%          nx: dimension x
%          nu: dimension u
%          ny: dimension y
%          mrp: optional, desired maximum value of real part of system poles
%          seed: optional, seed for random number generators
%
%          L.G. Van Willigenburg, W.L. De Koning, 28-11-95.
%
  function [p,g,c,v,w,q,r]=crlqg(nx,nu,ny,mrp,seed);
  if nargin==5; ; elseif nargin==4 seed=[]; elseif nargin==3
    mrp=[]; seed==[];
  else error('Wrong number of input arguments'); end;
  if max(size(seed))~=0; rand('seed',seed); randn('seed',seed); end;
  [p,g,c,d]=rmodel(nx,ny,nu);
  if max(size(mrp))~=0;
    mr=max(real(eig(p))); p=p+(mrp-mr)*eye(nx);
  end;
  p=round(1e4*p)/1e4; g=round(1e4*g)/1e4; c=round(1e4*c)/1e4;
  v=diag(rand(nx,1)); w=diag(rand(ny,1));
  q=diag(rand(nx,1)); r=diag(rand(nu,1));
  q=round(1e4*q)/1e4; r=round(1e4*r)/1e4;
  v=round(1e4*v)/1e4; w=round(1e4*w)/1e4;

