%DELLYAP: Delta Lyapunov equation solution.
%         X=DELLYAP(A,C,delta) solves the delta Lyapunov equation:
%         delta*A*X*A' + AX + XA + C = 0
%
%         [x] = dellyap(a,c,delta)
%
%         See also LYAP, DLYAP, DELGRAM
%
%         GvW 21-3-2000

function p = dellyap(a,c,delta)

error(nargchk(3,3,nargin));
error(abcdchk(a,c));

if ~ maxreig(a,delta) < 0;
   error('A not asymptotically stable. Execution aborted');
end;

I = eye(size(a));
Ac = I + (delta * a) / 2;
if det(Ac) == 0
    error('No unique solution. Execution aborted');
else
    c = Ac \ c / (I + (delta * a') / 2);
    a = Ac \ a;
    p = lyap(a,c);   
end
