% DELROEQ :One iteration of the Delta Deterministic Parameter
%          Reduced-Order LQG EQuations.
%          Control and estimation equations of compensator
%          for (P,G,C,V,W) based on (Q,R) and nc=<nx.
%          (P,G,C) deterministic.
%
%          [pt,ph,st,sh,tps,psi1,psi2]=delroeq(pt,ph,st,sh,p,g,c,v,w,q,r,delta,nc,a,dt,b,m,rtol);
%
%          See also delrotin, gmhfa
%
%          W.L. De Koning, L.G. Van Willigenburg, 28-11-95.
%

  function [pt,ph,st,sh,tps,psi1,psi2,ta]=delroeq(pt,ph,st,sh,p,g,c,v,w,q,r,mc,me,delta,nc,a,dt,b,m,rtol)

% Determine nx,nu                                         
  [nx,nu]=size(g);

%
% full order equations
%
  wp=w+delta*c*pt*c'            ; rs=r+delta*g'*st*g;
  iwp=pinv(wp)                  ; irs=pinv(rs);
%  kh=me+(eye(nx)+delta*p)*pt*c'    ; lh=g'*st*(eye(nx)+delta*p)+mc';
  kh=me+pt*c'+delta*p*pt*c'     ; lh=g'*st+delta*g'*st*p+mc';
  s1p=kh*iwp*kh'                ; s2s=lh'*irs*lh;
  p1p=p-kh*iwp*c                ; p2s=p-g*irs*lh;
  shp1p=sh*p1p                  ; php2s=ph*p2s';
  ppt=p*pt                      ; pst=p'*st;

  psi1=delta*p2s *ph*p2s'+s1p+php2s+php2s';
  psi2=delta*p1p'*sh*p1p +s2s+shp1p+shp1p';
  ptd=delta*p *pt*p'-s1p+v+ppt+ppt';
  std=delta*p'*st*p -s2s+q+pst+pst';

% Reduced order adaptation ptd,std
  [ta]=gmhfac(ph,sh,nc,a,m,rtol); tao=eye(nx)-ta;
  ptd=ptd+tao*psi1*tao'; std=std+tao'*psi2*tao;

% Trace expression that determines convergence
  tps1=abs(trace(ptd+std)); tps2=abs(trace(pt+st));
  tps=[tps2;tps1/(tps2+1e-40)];

% Delta update ptu,stu,phu,shu
  if delta<=dt; delta=dt; end;
  ptu=pt+delta*ptd ; stu=st+delta*std;
  phu=ph+delta*psi1; shu=sh+delta*psi2;

% Reduced order adaptation
  ptu=ptu+tao*ph*tao';
  stu=stu+tao'*sh*tao ;   
  phu=phu*ta'; phu=0.5*(phu+phu');
  shu=shu*ta ; shu=0.5*(shu+shu');

% Update pt,st,ph,sh & stability improvements    
  pt=(1-b)*ptu+b*pt; pt=0.5*(pt+pt');
  st=(1-b)*stu+b*st; st=0.5*(st+st');
  ph=(1-b)*phu+b*ph; sh=(1-b)*shu+b*sh;