% DELROEQC:one iteration of the Deterministic Parameter
%          Reduced-Order LQG Control EQuation.
%          Control equations of compensator
%          for (P,G,C) and nc=<nx.
%
%          function [st,sh]=delroeqc(p,g,c,v,w,q,r,mc,me,st,sh,pt,ph,ta,delta,dt,ap);
%
%          W.L. De Koning, L.G. Van Willigenburg, 28-11-95.
%

  function [st,sh]=delroeqc(p,g,c,v,w,q,r,mc,me,st,sh,pt,ph,ta,delta,dt,ap);

  [nx,nu]=size(g);
%
% full order equations
%
  wp=w+delta*c*pt*c'            ; rs=r+delta*g'*st*g;
  iwp=pinv(wp)                  ; irs=pinv(rs);
%  kh=(eye(nx)+delta*p)*pt*c'    ; lh=g'*st*(eye(nx)+delta*p);
  kh=me+pt*c'+delta*p*pt*c'     ; lh=g'*st+delta*g'*st*p+mc';
  s2s=lh'*irs*lh                ; p1p=p-kh*iwp*c;
  shp1p=sh*p1p;                 ; pst=p'*st;

  psi2=delta*p1p'*sh*p1p +s2s+shp1p+shp1p';

% computation tao
  tao=eye(nx)-ta;

% increments st,sh
  dsh=psi2; dst=delta*p'*st*p -s2s+q+pst+pst'+tao'*psi2*tao;

% new st,sh and reduced-order adaptation
  delta=max(delta,dt);
  st=delta*dst+st+tao'*sh*tao; st=0.5*(st+st');
  sh=delta*dsh+sh; sh=sh*ta  ; sh=0.5*(sh+sh');


