% DRLQG.M: Discrete-time random LQG problem generation.
%
%          function [p,g,c,v,w,q,r]=drlqg(nx,nu,ny,srp,seed);
%
% Input:
%          nx: dimension x
%          nu: dimension u
%          ny: dimension y
%          srp: optional, desired spectral radius p (system matrix).
%          seed: optional, seed for random number generator
%
%          L.G. Van Willigenburg, W.L. De Koning, 28-11-95.
%
  function [p,g,c,v,w,q,r]=drlqg(nx,nu,ny,srp,seed);
  if nargin==5; ; elseif nargin==4 seed=[]; elseif nargin==3
    srp=[]; seed==[];
  else error('Wrong number of input arguments'); end;
  if max(size(seed))~=0; rand('seed',seed); end;
  [p,g,c]=drmodel(nx,ny,nu);
  if max(size(srp))~=0 & srp>0 ; p=srp*p/sperad(p); end;
  p=round(1e4*p)/1e4; g=round(1e4*g)/1e4; c=round(1e4*c)/1e4;
  v=diag(rand(nx,1)); w=diag(rand(ny,1));
  q=diag(rand(nx,1)); r=diag(rand(nu,1));
% Round numbers to 5 decimal digits
  v=round(1e4*v)/1e4; w=round(1e4*w)/1e4;
  q=round(1e4*q)/1e4; r=round(1e4*r)/1e4;
