%  Example 1 in : L.G. van Willigenburg, W.L. De Koning, 2000,
%  "Finite and infinite horizon fixed-order LQG compensation
%  using the delta operator", Proceedings UKACC International
%  Conference on Control 2000, 4-7 September, Cambridge, UK,
%  (paper002.pdf)
%
%  GvW/WdK

clear all; close all; clc; format;

% Discrete-time problem
[p,g,c,v,w,q,r]=drlqg(2,1,1,0.95,10); p=p';
nc=1; opt(6)=2; opt(4)=50; randn('seed',1); rand('seed',1);
% Discrete-time optimal compensators
[f,k,l,sigp,sigs,spr,pt,st,ph,sh,sigc,trps]=dprotin(p,g,c,v,w,q,r,nc,opt);
disp([' Discrete-time solution 1 : sigp = ' num2str(sigp) ', sigs = ' num2str(sigs)]);
nc=1; opt(6)=2; opt(4)=50; randn('seed',4); rand('seed',4);
[f,k,l,sigp,sigs,spr,pt,st,ph,sh,sigc,trps]=dprotin(p,g,c,v,w,q,r,nc,opt);
disp([' Discrete-time solution 2 : sigp = ' num2str(sigp) ', sigs = ' num2str(sigs)]);
for delta = [10 2 1 0.5 0.1 1e-2 1e-3]
  % Conversion to delta domain
  [pd,gd,cd,dd] = z2del(p,g,c,zeros(1),delta);
  qd=q/delta; vd=v/delta; rd=r/delta; wd=delta*w;
  % Delta compensators
  rand('seed',1); randn('seed',1);
  [fd,kd,ld,sigpd,sigsd,sprd,ptd,std,phd,shd,sigcd,it]=delrotin(pd,gd,cd,vd,wd,qd,rd,delta,nc,opt);
  disp([' Solution 1, delta = ' num2str(delta) ' : sigpd = ' num2str(sigpd) ' sigsd = ' num2str(sigsd)]);
  rand('seed',4); randn('seed',4);
  [fd,kd,ld,sigpd,sigsd,sprd,ptd,std,phd,shd,sigcd,it]=delrotin(pd,gd,cd,vd,wd,qd,rd,delta,nc,opt);
  disp([' Solution 2, delta = ' num2str(delta) ' : sigpd = ' num2str(sigpd) ' sigsd = ' num2str(sigsd)]);
end