%  Example 2 in : L.G. van Willigenburg, W.L. De Koning, 2000,
%  "Finite and infinite horizon fixed-order LQG compensation
%  using the delta operator", Proceedings UKACC International
%  Conference on Control 2000, 4-7 September, Cambridge, UK,
%  (paper002.pdf)
%
%  GvW/WdK

  clear all; close all; clc; format;
  
  global p_ g_ c_ v_ w_ q_ r_ nc_ H_ x0c_ N_ x0m_ delta_ dt_
  
  % Discrete-time problem
  [p_,g_,c_,v_,w_,q_,r_]=drlqg(2,1,1,0.95,10); p_=p_';
  N_=10; nc_=1; H_=diag([0.1 0.1]); x0c_=H_; x0m_=[1;1];
  
  % Discrete-time optimal compensators
  opt=[]; opt(1)=1e-7; opt(4)=50; opt(6)=2;
  randn('seed',1); rand('seed',1);
  [xfkl,sigp,sigs,ptt,stt,pht,sht,trps]=dprotv('delfutv',opt);
  disp([' Discrete-time solution 1 : sigp = ' num2str(sigp) ', sigs = ' num2str(sigs)]);
  randn('seed',3); rand('seed',3);
  [xfkl,sigp,sigs,ptt,stt,pht,sht,trps]=dprotv('delfutv',opt);
  disp([' Discrete-time solution 2 : sigp = ' num2str(sigp) ', sigs = ' num2str(sigs)]);

  for delta_=[10 2 1 0.5 0.1 1e-2 1e-3]
    % Discrete-time problem
    [p_,g_,c_,v_,w_,q_,r_]=drlqg(2,1,1,0.95,10); p_=p_';
    
    % Conversion to delta domain
    dt_=delta_; p_=(p_-eye(size(p_)))/delta_; g_=g_/delta_;
    q_=q_/delta_; v_=v_/delta_; r_=r_/delta_; w_=delta_*w_;

    % Delta optimal compensators
    rand('seed',1); randn('seed',1);
    [xfkld,sigpd,sigsd,pttd,sttd,phtd,shtd,trpsd]=delrotv('delfutv',opt);
    disp([' Solution 1, delta = ' num2str(delta_) ' : sigpd = ' num2str(sigpd) ' sigsd = ' num2str(sigsd)]);
    rand('seed',21); randn('seed',21);
    [xfkld,sigpd,sigsd,pttd,sttd,phtd,shtd,trpsd]=delrotv('delfutv',opt);
    disp([' Solution 2, delta = ' num2str(delta_) ' : sigpd = ' num2str(sigpd) ' sigsd = ' num2str(sigsd)]);
  end