% MAXREIG: Stability measure for continuous-time systems and
%          discrete-time systems described with the delta operator.
%
%          Function computes max(real(eig(a))) if delta=0 or not specified
%          and max(real(eig(a))+abs(eig(a)).^2*delta/2) if delta > 0
%
%          If the outcome is < 0 then the associated system is stable
%
%          [mre]=maxreig(a,delta)
%
function [mre]=maxreig(a,delta)

if nargin==1; delta=0; end;

[nh,mh]=size(a);
if nh~=mh; error(' a must be square'); end;

[nh,mh]=size(delta);
if nh~=1 || mh~=1; error(' delta must be a scalar'); end;

if delta<0; error(' delta >= 0 violated'); end;

d=eig(a); mre=max(abs(d).^2*delta/2+real(d));
