% PSDR: Generate a random positive semi-definite
%       nx x nx matrix of rank nc.
%
%       function [psd]=psdr(nx,nc)
%
% optional input: nc (nc=nx is assumed otherwise).
%
%        L.G. Van Willigenburg, W.L. De Koning, 28-11-95.
%
  function [psd]=psdr(nx,nc)

  if nx<0 | rem(nx,1)~=0;
    error('nx must be an integer > 0'); end;
  if nargin>1
    if nc<0 | nc>nx | rem(nc,1)~=0;
      error('nc must be an integer 0<=nc<=nx'); end;
  else; nc=nx; end;
  if nc==0; psd=zeros(nx);
  else;
    psd=randn(nx,nx); [u,d,v]=svd(psd); d=diag(d);
    y=u(:,1:nc)*diag(sqrt(d(1:nc)));
    psd=y*y'; end

